nxtools
=======

nxtools is a set of various tools and helpers used by Nebula_ and other software.

Installation
------------

``pip install nxtools``

Modules
-------

- **nxtools.files** - file and path manipulation utilities
- **nxtools.ffmpeg** - ffmpeg and ffprobe wrappers
- **nxtools.common** - common utilities
- **nxtools.logging** - provides logging class 
- **nxtools.timeutils** - time format conversion utilities
- **nxtools.shell** - executing external programs
- **nxtools.misc** - string formating etc

.. _Nebula: https://github.com/immstudios/nebula
